TextDocument

Struct TextDocument 

pub struct TextDocument<'a> {
    pub id: &'a str,
    pub text: &'a str,
    pub language: Option<&'a str>,
    pub timestamp: Option<Timestamp>,
}
Borrowed text document used as the lightweight boundary between text crates.

Fields

id: &'a str

Stable caller-supplied document id.

text: &'a str

UTF-8 document body.

language: Option<&'a str>

Optional BCP-47-style language hint such as en.

timestamp: Option<Timestamp>

Optional media timestamp when this document came from a timed segment.

Implementations

Source

impl<'a> TextDocument<'a>

pub fn new(id: &'a str, text: &'a str) -> Self

Creates a new value.

pub fn from_segment_id(id: &'a str, segment: &TextSegment<'a>) -> Self

Builds this value from segment identifier.

pub fn from_stream_segment( stream_id: &str, segment: &TextSegment<'_>, ) -> OwnedTextDocument

Builds this value from stream segment.

pub fn from_segment(stream_id: &'a str, segment: &TextSegment<'a>) -> Self

Builds a document using stream_id directly as the document id.

Prefer TextDocument::from_segment_id when the id has already been chosen, or TextDocument::from_stream_segment when converting a stream segment into the canonical stream_id:segment_index id.